@@ -1886,7 +1886,9 @@ class WebSocket(AbstractModel):
 
     def __init__(self):
         """
-        :param Switch: WebSocket配置开关，on或off。
+        :param Switch: WebSocket 超时配置开关, 开关为off时，平台仍支持WebSocket连接，此时超时时间默认为15秒，若需要调整超时时间，将开关置为on.
+
+* WebSocket 为内测功能,如需使用,请联系腾讯云工程师开白.
         :type Switch: str
         :param Timeout: 设置超时时间，单位为秒，最大超时时间65秒。
 注意：此字段可能返回 null，表示取不到有效值。
